@@ -316,6 +316,7 @@ brasero_task_ctx_set_next_track (BraseroTaskCtx *self)
 	priv->session_bytes += priv->track_bytes;
 	priv->track_bytes = 0;
 	priv->last_written = 0;
+	priv->progress = 0;
 
 	if (priv->current_track)
 		g_object_unref (priv->current_track);
@@ -866,7 +867,7 @@ brasero_task_ctx_get_remaining_time (BraseroTaskCtx *self,
 		return BRASERO_BURN_NOT_READY;
 
 	elapsed = g_timer_elapsed (priv->timer, NULL);
-	*remaining = (gdouble) priv->total_time - (gdouble) elapsed;
+	*remaining = priv->total_time - elapsed;
 
 	return BRASERO_BURN_OK;
 }
