@@ -1319,7 +1319,7 @@ brasero_project_install_missing (BraseroPluginErrorType type,
 
 	/* Get the xid */
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (project));
-	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (GTK_WIDGET (parent)->window));
+	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (gtk_widget_get_window (parent)));
 
 	package = brasero_pk_new ();
 	cancel = g_cancellable_new ();
@@ -1368,12 +1368,15 @@ brasero_project_list_missing (BraseroPluginErrorType type,
 {
 	GString *string = user_data;
 
-	if (type == BRASERO_PLUGIN_ERROR_MISSING_APP) {
+	if (type == BRASERO_PLUGIN_ERROR_MISSING_APP ||
+	    type == BRASERO_PLUGIN_ERROR_SYMBOLIC_LINK_APP ||
+	    type == BRASERO_PLUGIN_ERROR_WRONG_APP_VERSION) {
 		g_string_append_c (string, '\n');
 		/* Translators: %s is the name of a missing application */
 		g_string_append_printf (string, _("%s (application)"), detail);
 	}
-	else if (type == BRASERO_PLUGIN_ERROR_MISSING_LIBRARY) {
+	else if (type == BRASERO_PLUGIN_ERROR_MISSING_LIBRARY ||
+	         type == BRASERO_PLUGIN_ERROR_LIBRARY_VERSION) {
 		g_string_append_c (string, '\n');
 		/* Translators: %s is the name of a missing library */
 		g_string_append_printf (string, _("%s (library)"), detail);
@@ -1627,7 +1630,6 @@ brasero_project_burn (BraseroProject *project)
 	project->priv->current = NULL;
 
 	brasero_dest_selection_set_session (BRASERO_DEST_SELECTION (project->priv->selection), NULL);
-
 	brasero_project_setup_session (project, BRASERO_BURN_SESSION (project->priv->session));
 
 	/* This is to stop the preview widget from playing */
@@ -1643,11 +1645,12 @@ brasero_project_burn (BraseroProject *project)
 
 	project->priv->current = current_disc;
 	brasero_disc_set_session_contents (current_disc, BRASERO_BURN_SESSION (project->priv->session));
-
 	brasero_dest_selection_set_session (BRASERO_DEST_SELECTION (project->priv->selection),
 					    BRASERO_BURN_SESSION (project->priv->session));
 
 	project->priv->is_burning = 0;
+
+	brasero_project_update_controls (project);
 }
 
 /******************************** cover ****************************************/
