@@ -236,7 +236,7 @@ brasero_main_burning_device (const gchar *option_name,
 		if (!brasero_drive_can_write (burner)) {
 			gchar *string;
 
-			/* Translators: %s is the path of a drive */
+			/* Translators: %s is the path of drive */
 			string = g_strdup_printf (_("\"%s\" cannot write."), value);
 			brasero_utils_message_dialog (NULL,
 						      _("Wrong command line option."),
@@ -348,17 +348,12 @@ brasero_app_parse_options (BraseroApp *app)
 			return;
 	}
 	else if (burn_project_uri) {
-		gboolean res;
-
-		res = brasero_app_open_project (app,
-		                                burner,
-		                                burn_project_uri,
-		                                FALSE,
-		                                TRUE,
-		                                FALSE /* This is to keep the current behavior which is open main window */);
-		if (res)
-			brasero_app_run_mainwin (app);
-
+		brasero_app_open_project (app,
+					  burner,
+					  burn_project_uri,
+					  FALSE,
+					  TRUE,
+					  burn_immediately != 0 /* This is to keep the current behavior which is open main window */);
 		if (g_remove (burn_project_uri) != 0) {
 			gchar *path;
 
@@ -468,11 +463,6 @@ main (int argc, char **argv)
 	g_thread_init (NULL);
 	g_type_init ();
 
-	/* Though we use gtk_get_option_group we nevertheless want gtk+ to be
-	 * in a usable state to display our error messages while brasero
-	 * specific options are parsed. Otherwise on error that crashes. */
-	gtk_init (&argc, &argv);
-
 	context = g_option_context_new (_("[URI] [URI] …"));
 	g_option_context_add_main_entries (context,
 					   options,
